<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Face ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem-sucedida</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>A verificação falhou, restam %n tentativas</numerusform><numerusform>A verificação falhou, restam %n tentativas</numerusform><numerusform>A verificação falhou, restam %n tentativas</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>A verificação falhou; resta apenas uma tentativa</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Verifique seu Face ID</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Face ID bloqueado, use a senha</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>Dispositivo indisponível!</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Verifique a impressão digital</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem-sucedida</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>A verificação falhou, restam %n tentativas</numerusform><numerusform>A verificação falhou, restam %n tentativas</numerusform><numerusform>A verificação falhou, restam %n tentativas</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>A verificação falhou; resta apenas uma tentativa</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Impressão digital bloqueada; utilize a senha</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>Íris ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem-sucedida</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>A verificação falhou, restam %n tentativas</numerusform><numerusform>A verificação falhou, restam %n tentativas</numerusform><numerusform>A verificação falhou, restam %n tentativas</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>A verificação falhou; resta apenas uma tentativa</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Verifique sua Íris ID</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>Íris ID bloqueado, use a senha</translation>
    </message>
</context>
<context>
    <name>AuthPasskey</name>
    <message>
        <source>Please plug in the security key</source>
        <translation>Conecte a chave de segurança</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem-sucedida</translation>
    </message>
    <message>
        <source>Verification failed</source>
        <translation>A verificação falhou</translation>
    </message>
    <message>
        <source>Identifying the security key</source>
        <translation>Identificando chave de segurança</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem-sucedida</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>A verificação falhou, restam %n tentativas</numerusform><numerusform>A verificação falhou, restam %n tentativas</numerusform><numerusform>A verificação falhou, restam %n tentativas</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>A verificação falhou; resta apenas uma tentativa</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Senha Incorreta</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Tente novamente em 1 minuto</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Tente novamente em %n minuto(s)</numerusform><numerusform>Tente novamente em %n minuto(s)</numerusform><numerusform>Tente novamente em %n minuto(s)</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Redefinir senha</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Esqueceu a senha?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Tente novamente em 1 minuto</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Tente novamente em %n minuto(s)</numerusform><numerusform>Tente novamente em %n minuto(s)</numerusform><numerusform>Tente novamente em %n minuto(s)</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Redefinir senha</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Esqueceu a senha?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem-sucedida</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>A verificação falhou, restam %n tentativas</numerusform><numerusform>A verificação falhou, restam %n tentativas</numerusform><numerusform>A verificação falhou, restam %n tentativas</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>A verificação falhou; resta apenas uma tentativa</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PIN incorreto</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>A UKey é necessária</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Insira seu PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Tente novamente em %n minuto(s)</numerusform><numerusform>Tente novamente em %n minuto(s)</numerusform><numerusform>Tente novamente em %n minuto(s)</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Tente novamente em 1 minuto</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Tente novamente em %n minuto(s)</numerusform><numerusform>Tente novamente em %n minuto(s)</numerusform><numerusform>Tente novamente em %n minuto(s)</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Conta</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>Sua senha expirará em %n dia, altere-a em tempo hábil</numerusform><numerusform>Sua senha expirará em %n dias, altere-a em tempo hábil</numerusform><numerusform>Sua senha expirará em %n dias, altere-a em tempo hábil</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>A senha expirou; altere-a</translation>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it</source>
        <translation>Sua senha expirou. Entre em contato com o administrador para alterá-la</translation>
    </message>
    <message>
        <source>Terminal locked, please contact administrator</source>
        <translation>Terminal bloqueado, entre em contato com o administrador</translation>
    </message>
</context>
<context>
    <name>DeepinAuthFramework</name>
    <message>
        <source>Wrong Password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Conta incorreta</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Senha Incorreta</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>The reason of inhibit.</source>
        <translation>O motivo da inibição.</translation>
    </message>
</context>
<context>
    <name>LighterGreeter</name>
    <message>
        <source>Standard Mode</source>
        <translation>Modo Padrão</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Bloquear Tela</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Falha ao bloquear a tela</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>O tempo de verificação da impressão digital expirou, insira sua senha manualmente</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Falha ao coincidir a impressão digital</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Os usuários acima ainda estão conectados e os dados serão perdidos devido ao desligamento. Desligar?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Os usuários acima ainda estão conectados e os dados serão perdidos devido à reinicialização. Reiniciar?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Você ativou o nível alto de segurança do sistema e, portanto, não pode alternar para o modo Wayland. Desative o nível alto de segurança na Central de Segurança e tente novamente.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Trocar usuário</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Alternar sistema</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Atualizar e desligar</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Atualizar e reiniciar</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Monitor de Sistema</translation>
    </message>
</context>
<context>
    <name>UdcpMFALoginWidget</name>
    <message>
        <source>发送验证码</source>
        <translation>Enviar código de verificação</translation>
    </message>
    <message>
        <source>请输入手机号</source>
        <translation>Digite o número de telefone</translation>
    </message>
    <message>
        <source>请输入验证码</source>
        <translation>Digite o código de verificação</translation>
    </message>
    <message>
        <source>获取验证码</source>
        <translation>Obter código de verificação</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>Update</source>
        <translation>Atualizar</translation>
    </message>
    <message>
        <source>Please plug in and then install updates.</source>
        <translation>Conecte o carregador para instalar as atualizações.</translation>
    </message>
</context>
<context>
    <name>UsersWithTheSameName</name>
    <message>
        <source>Return</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please select the account for login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Local Account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Domain Account</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador seja desligado; e forçar o desligamento, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Para fechar o aplicativo, clique em Cancelar e depois feche-o.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador seja reiniciado; e forçar a reinicialização, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador seja suspenso; e forçar a suspensão, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador seja hibernado; e forçar a hibernação, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador encerre a sessão; e forçar o encerramento da sessão, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Desligar?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Reiniciar?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Sair?</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Atualizar e desligar</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Atualizar e reiniciar</translation>
    </message>
    <message>
        <source>Closing the programs and shutting down, please wait...</source>
        <translation>Fechando os programas e desligando, aguarde...</translation>
    </message>
    <message>
        <source>Closing the programs and rebooting, please wait...</source>
        <translation>Fechando os programas e reiniciando, aguarde...</translation>
    </message>
    <message>
        <source>Closing the programs and logging out, please wait...</source>
        <translation>Fechando os programas e saindo, aguarde...</translation>
    </message>
</context>
<context>
    <name>dss::module::AssistLoginWidget</name>
    <message>
        <source>Automatic login</source>
        <translation>Login automático</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Ativar</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Desativar</translation>
    </message>
</context>
</TS>